@@ -19,6 +19,7 @@ package dal
 
 import (
 	"database/sql"
+	"fmt"
 	"reflect"
 
 	"github.com/apache/incubator-devlake/core/errors"
@@ -154,6 +155,8 @@ type Dal interface {
 	AllTables() ([]string, errors.Error)
 	// DropTables drops all specified tables
 	DropTables(dst ...interface{}) errors.Error
+	// HasTable checks if table exists
+	HasTable(table interface{}) bool
 	// RenameTable renames table name
 	RenameTable(oldName, newName string) errors.Error
 	// GetColumns returns table columns in database
@@ -239,7 +242,8 @@ func GetPrimarykeyColumnNames(d Dal, dst Tabler) (names []string, err errors.Err
 		return
 	}
 	for _, pkColumn := range pkColumns {
-		names = append(names, pkColumn.Name())
+		// in case the column name is a reserved identifier
+		names = append(names, fmt.Sprintf("%s.%s", dst.TableName(), pkColumn.Name()))
 	}
 	return
 }
