@@ -75,5 +75,10 @@ func All() []plugin.MigrationScript {
 		new(addCommitShaIndex),
 		new(removeCreatedDateAfterFromCollectorMeta20230223),
 		new(addHostNamespaceRepoName),
+		new(renameCollectorTapStateTable),
+		new(renameCicdPipelineRepoToRepoUrl),
+		new(addCicdDeploymentCommits),
+		new(renameDeploymentIdForPrProjectMetric),
+		new(addCommitAuthoredDate),
 	}
 }
