@@ -31,5 +31,10 @@ func All() []plugin.MigrationScript {
 		new(addRepoIdAndCommitShaField20221014),
 		new(addScope20230206),
 		new(addPipelineStep20230215),
+		new(addConnectionIdToTransformationRule),
+		new(addTypeEnvToPipelineAndStep),
+		new(addRepoIdField20230411),
+		new(addRepoIdToPr),
+		new(addBitbucketCommitAuthorInfo),
 	}
 }
