@@ -34,5 +34,9 @@ func All() []plugin.MigrationScript {
 		new(addTransformationRule20221124),
 		new(concatOwnerAndName),
 		new(addStdTypeToIssue221230),
+		new(addConnectionIdToTransformationRule),
+		new(addEnvToRunAndJob),
+		new(addGithubCommitAuthorInfo),
+		new(fixRunNameToText),
 	}
 }
