@@ -21,6 +21,7 @@ import (
 	"encoding/json"
 
 	"github.com/apache/incubator-devlake/core/errors"
+	"github.com/apache/incubator-devlake/core/models/domainlayer/devops"
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 	"github.com/apache/incubator-devlake/plugins/gitlab/models"
@@ -80,16 +81,22 @@ func ExtractApiPipelines(taskCtx plugin.SubTaskContext) errors.Error {
 			}
 
 			gitlabPipeline := &models.GitlabPipeline{
-				GitlabId:         gitlabApiPipeline.Id,
-				ProjectId:        data.Options.ProjectId,
-				WebUrl:           gitlabApiPipeline.WebUrl,
-				Status:           gitlabApiPipeline.Status,
-				GitlabCreatedAt:  api.Iso8601TimeToTime(gitlabApiPipeline.CreatedAt),
-				GitlabUpdatedAt:  api.Iso8601TimeToTime(gitlabApiPipeline.UpdatedAt),
-				StartedAt:        api.Iso8601TimeToTime(gitlabApiPipeline.StartedAt),
-				FinishedAt:       api.Iso8601TimeToTime(gitlabApiPipeline.FinishedAt),
-				Duration:         gitlabApiPipeline.Duration,
-				ConnectionId:     data.Options.ConnectionId,
+				GitlabId:        gitlabApiPipeline.Id,
+				ProjectId:       data.Options.ProjectId,
+				Ref:             gitlabApiPipeline.Ref,
+				Sha:             gitlabApiPipeline.Sha,
+				WebUrl:          gitlabApiPipeline.WebUrl,
+				Status:          gitlabApiPipeline.Status,
+				GitlabCreatedAt: api.Iso8601TimeToTime(gitlabApiPipeline.CreatedAt),
+				GitlabUpdatedAt: api.Iso8601TimeToTime(gitlabApiPipeline.UpdatedAt),
+				StartedAt:       api.Iso8601TimeToTime(gitlabApiPipeline.StartedAt),
+				FinishedAt:      api.Iso8601TimeToTime(gitlabApiPipeline.FinishedAt),
+				Duration:        gitlabApiPipeline.Duration,
+				ConnectionId:    data.Options.ConnectionId,
+
+				Type:        data.RegexEnricher.ReturnNameIfMatched(devops.DEPLOYMENT, gitlabApiPipeline.Ref),
+				Environment: data.RegexEnricher.ReturnNameIfOmittedOrMatched(devops.PRODUCTION, gitlabApiPipeline.Ref),
+
 				IsDetailRequired: false,
 			}
 
