@@ -135,6 +135,9 @@ func (p Jira) SubTaskMetas() []plugin.SubTaskMeta {
 		tasks.ConvertSprintsMeta,
 		tasks.ConvertSprintIssuesMeta,
 
+		tasks.CollectDevelopmentPanelMeta,
+		tasks.ExtractDevelopmentPanelMeta,
+
 		tasks.ConvertIssueCommitsMeta,
 		tasks.ConvertIssueRepoCommitsMeta,
 
@@ -164,9 +167,6 @@ func (p Jira) PrepareTaskData(taskCtx plugin.TaskContext, options map[string]int
 		taskCtx,
 		nil,
 	)
-	if err != nil {
-		return nil, errors.BadInput.Wrap(err, "could not get connection API instance for Jira")
-	}
 	err = connectionHelper.FirstById(connection, op.ConnectionId)
 	if err != nil {
 		return nil, errors.Default.Wrap(err, "unable to get Jira connection")
@@ -224,6 +224,11 @@ func (p Jira) PrepareTaskData(taskCtx plugin.TaskContext, options map[string]int
 		}
 	}
 
+	// set default page size
+	if op.PageSize <= 0 || op.PageSize > 100 {
+		op.PageSize = 100
+	}
+
 	info, code, err := tasks.GetJiraServerInfo(jiraApiClient)
 	if err != nil || code != http.StatusOK || info == nil {
 		return nil, errors.HttpStatus(code).Wrap(err, "fail to get Jira server info")
@@ -283,7 +288,7 @@ func (p Jira) ApiResources() map[string]map[string]plugin.ApiResourceHandler {
 		"connections/:connectionId/proxy/rest/*path": {
 			"GET": api.Proxy,
 		},
-		"connections/:connectionId/scopes/:boardId": {
+		"connections/:connectionId/scopes/:scopeId": {
 			"GET":   api.GetScope,
 			"PATCH": api.UpdateScope,
 		},
@@ -291,14 +296,20 @@ func (p Jira) ApiResources() map[string]map[string]plugin.ApiResourceHandler {
 			"GET": api.GetScopeList,
 			"PUT": api.PutScope,
 		},
-		"transformation_rules": {
+		"connections/:connectionId/transformation_rules": {
 			"POST": api.CreateTransformationRule,
 			"GET":  api.GetTransformationRuleList,
 		},
-		"transformation_rules/:id": {
+		"connections/:connectionId/transformation_rules/:id": {
 			"PATCH": api.UpdateTransformationRule,
 			"GET":   api.GetTransformationRule,
 		},
+		"connections/:connectionId/application-types": {
+			"GET": api.GetApplicationTypes,
+		},
+		"connections/:connectionId/dev-panel-commits": {
+			"GET": api.GetCommitsURLs,
+		},
 	}
 }
 
