@@ -33,5 +33,10 @@ func All() []plugin.MigrationScript {
 		new(removeIssueStdStoryPoint),
 		new(addCommitRepoPattern),
 		new(expandRemotelinkUrl),
+		new(addConnectionIdToTransformationRule),
+		new(addChangeTotal20230412),
+		new(expandRemotelinkSelfUrl),
+		new(addRepoUrl),
+		new(addApplicationType),
 	}
 }
