@@ -75,7 +75,7 @@ func ExtractIssues(taskCtx plugin.SubTaskContext) errors.Error {
 			Table: RAW_ISSUE_TABLE,
 		},
 		Extract: func(row *api.RawData) ([]interface{}, errors.Error) {
-			return extractIssues(data, mappings, false, row)
+			return extractIssues(data, mappings, row)
 		},
 	})
 	if err != nil {
@@ -84,7 +84,7 @@ func ExtractIssues(taskCtx plugin.SubTaskContext) errors.Error {
 	return extractor.Execute()
 }
 
-func extractIssues(data *JiraTaskData, mappings *typeMappings, ignoreBoard bool, row *api.RawData) ([]interface{}, errors.Error) {
+func extractIssues(data *JiraTaskData, mappings *typeMappings, row *api.RawData) ([]interface{}, errors.Error) {
 	var apiIssue apiv2models.Issue
 	err := errors.Convert(json.Unmarshal(row.Data, &apiIssue))
 	if err != nil {
@@ -95,6 +95,10 @@ func extractIssues(data *JiraTaskData, mappings *typeMappings, ignoreBoard bool,
 		return nil, err
 	}
 	var results []interface{}
+	// if the field `created` is nil, ignore it
+	if apiIssue.Fields.Created == nil {
+		return results, nil
+	}
 	sprints, issue, worklogs, changelogs, changelogItems, users := apiIssue.ExtractEntities(data.Options.ConnectionId)
 	for _, sprintId := range sprints {
 		sprintIssue := &models.JiraSprintIssue{
@@ -156,13 +160,11 @@ func extractIssues(data *JiraTaskData, mappings *typeMappings, ignoreBoard bool,
 			results = append(results, user)
 		}
 	}
-	if !ignoreBoard {
-		results = append(results, &models.JiraBoardIssue{
-			ConnectionId: data.Options.ConnectionId,
-			BoardId:      data.Options.BoardId,
-			IssueId:      issue.IssueId,
-		})
-	}
+	results = append(results, &models.JiraBoardIssue{
+		ConnectionId: data.Options.ConnectionId,
+		BoardId:      data.Options.BoardId,
+		IssueId:      issue.IssueId,
+	})
 	labels := apiIssue.Fields.Labels
 	for _, v := range labels {
 		issueLabel := &models.JiraIssueLabel{
