@@ -112,51 +112,51 @@ type TapdBug struct {
 	CustomFieldThree string `json:"custom_field_three" gorm:"type:text"`
 	CustomFieldFour  string `json:"custom_field_four" gorm:"type:text"`
 	CustomFieldFive  string `json:"custom_field_five" gorm:"type:text"`
-	CustomField6     string `json:"custom_field_6" gorm:"type:text"`
-	CustomField7     string `json:"custom_field_7" gorm:"type:text"`
-	CustomField8     string `json:"custom_field_8" gorm:"type:text"`
-	CustomField9     string `json:"custom_field_9" gorm:"type:text"`
-	CustomField10    string `json:"custom_field_10" gorm:"type:text"`
-	CustomField11    string `json:"custom_field_11" gorm:"type:text"`
-	CustomField12    string `json:"custom_field_12" gorm:"type:text"`
-	CustomField13    string `json:"custom_field_13" gorm:"type:text"`
-	CustomField14    string `json:"custom_field_14" gorm:"type:text"`
-	CustomField15    string `json:"custom_field_15" gorm:"type:text"`
-	CustomField16    string `json:"custom_field_16" gorm:"type:text"`
-	CustomField17    string `json:"custom_field_17" gorm:"type:text"`
-	CustomField18    string `json:"custom_field_18" gorm:"type:text"`
-	CustomField19    string `json:"custom_field_19" gorm:"type:text"`
-	CustomField20    string `json:"custom_field_20" gorm:"type:text"`
-	CustomField21    string `json:"custom_field_21" gorm:"type:text"`
-	CustomField22    string `json:"custom_field_22" gorm:"type:text"`
-	CustomField23    string `json:"custom_field_23" gorm:"type:text"`
-	CustomField24    string `json:"custom_field_24" gorm:"type:text"`
-	CustomField25    string `json:"custom_field_25" gorm:"type:text"`
-	CustomField26    string `json:"custom_field_26" gorm:"type:text"`
-	CustomField27    string `json:"custom_field_27" gorm:"type:text"`
-	CustomField28    string `json:"custom_field_28" gorm:"type:text"`
-	CustomField29    string `json:"custom_field_29" gorm:"type:text"`
-	CustomField30    string `json:"custom_field_30" gorm:"type:text"`
-	CustomField31    string `json:"custom_field_31" gorm:"type:text"`
-	CustomField32    string `json:"custom_field_32" gorm:"type:text"`
-	CustomField33    string `json:"custom_field_33" gorm:"type:text"`
-	CustomField34    string `json:"custom_field_34" gorm:"type:text"`
-	CustomField35    string `json:"custom_field_35" gorm:"type:text"`
-	CustomField36    string `json:"custom_field_36" gorm:"type:text"`
-	CustomField37    string `json:"custom_field_37" gorm:"type:text"`
-	CustomField38    string `json:"custom_field_38" gorm:"type:text"`
-	CustomField39    string `json:"custom_field_39" gorm:"type:text"`
-	CustomField40    string `json:"custom_field_40" gorm:"type:text"`
-	CustomField41    string `json:"custom_field_41" gorm:"type:text"`
-	CustomField42    string `json:"custom_field_42" gorm:"type:text"`
-	CustomField43    string `json:"custom_field_43" gorm:"type:text"`
-	CustomField44    string `json:"custom_field_44" gorm:"type:text"`
-	CustomField45    string `json:"custom_field_45" gorm:"type:text"`
-	CustomField46    string `json:"custom_field_46" gorm:"type:text"`
-	CustomField47    string `json:"custom_field_47" gorm:"type:text"`
-	CustomField48    string `json:"custom_field_48" gorm:"type:text"`
-	CustomField49    string `json:"custom_field_49" gorm:"type:text"`
-	CustomField50    string `json:"custom_field_50" gorm:"type:text"`
+	CustomField6     string `json:"custom_field_6" gorm:"type:text;column:custom_field_6"`
+	CustomField7     string `json:"custom_field_7" gorm:"type:text;column:custom_field_7"`
+	CustomField8     string `json:"custom_field_8" gorm:"type:text;column:custom_field_8"`
+	CustomField9     string `json:"custom_field_9" gorm:"type:text;column:custom_field_9"`
+	CustomField10    string `json:"custom_field_10" gorm:"type:text;column:custom_field_10"`
+	CustomField11    string `json:"custom_field_11" gorm:"type:text;column:custom_field_11"`
+	CustomField12    string `json:"custom_field_12" gorm:"type:text;column:custom_field_12"`
+	CustomField13    string `json:"custom_field_13" gorm:"type:text;column:custom_field_13"`
+	CustomField14    string `json:"custom_field_14" gorm:"type:text;column:custom_field_14"`
+	CustomField15    string `json:"custom_field_15" gorm:"type:text;column:custom_field_15"`
+	CustomField16    string `json:"custom_field_16" gorm:"type:text;column:custom_field_16"`
+	CustomField17    string `json:"custom_field_17" gorm:"type:text;column:custom_field_17"`
+	CustomField18    string `json:"custom_field_18" gorm:"type:text;column:custom_field_18"`
+	CustomField19    string `json:"custom_field_19" gorm:"type:text;column:custom_field_19"`
+	CustomField20    string `json:"custom_field_20" gorm:"type:text;column:custom_field_20"`
+	CustomField21    string `json:"custom_field_21" gorm:"type:text;column:custom_field_21"`
+	CustomField22    string `json:"custom_field_22" gorm:"type:text;column:custom_field_22"`
+	CustomField23    string `json:"custom_field_23" gorm:"type:text;column:custom_field_23"`
+	CustomField24    string `json:"custom_field_24" gorm:"type:text;column:custom_field_24"`
+	CustomField25    string `json:"custom_field_25" gorm:"type:text;column:custom_field_25"`
+	CustomField26    string `json:"custom_field_26" gorm:"type:text;column:custom_field_26"`
+	CustomField27    string `json:"custom_field_27" gorm:"type:text;column:custom_field_27"`
+	CustomField28    string `json:"custom_field_28" gorm:"type:text;column:custom_field_28"`
+	CustomField29    string `json:"custom_field_29" gorm:"type:text;column:custom_field_29"`
+	CustomField30    string `json:"custom_field_30" gorm:"type:text;column:custom_field_30"`
+	CustomField31    string `json:"custom_field_31" gorm:"type:text;column:custom_field_31"`
+	CustomField32    string `json:"custom_field_32" gorm:"type:text;column:custom_field_32"`
+	CustomField33    string `json:"custom_field_33" gorm:"type:text;column:custom_field_33"`
+	CustomField34    string `json:"custom_field_34" gorm:"type:text;column:custom_field_34"`
+	CustomField35    string `json:"custom_field_35" gorm:"type:text;column:custom_field_35"`
+	CustomField36    string `json:"custom_field_36" gorm:"type:text;column:custom_field_36"`
+	CustomField37    string `json:"custom_field_37" gorm:"type:text;column:custom_field_37"`
+	CustomField38    string `json:"custom_field_38" gorm:"type:text;column:custom_field_38"`
+	CustomField39    string `json:"custom_field_39" gorm:"type:text;column:custom_field_39"`
+	CustomField40    string `json:"custom_field_40" gorm:"type:text;column:custom_field_40"`
+	CustomField41    string `json:"custom_field_41" gorm:"type:text;column:custom_field_41"`
+	CustomField42    string `json:"custom_field_42" gorm:"type:text;column:custom_field_42"`
+	CustomField43    string `json:"custom_field_43" gorm:"type:text;column:custom_field_43"`
+	CustomField44    string `json:"custom_field_44" gorm:"type:text;column:custom_field_44"`
+	CustomField45    string `json:"custom_field_45" gorm:"type:text;column:custom_field_45"`
+	CustomField46    string `json:"custom_field_46" gorm:"type:text;column:custom_field_46"`
+	CustomField47    string `json:"custom_field_47" gorm:"type:text;column:custom_field_47"`
+	CustomField48    string `json:"custom_field_48" gorm:"type:text;column:custom_field_48"`
+	CustomField49    string `json:"custom_field_49" gorm:"type:text;column:custom_field_49"`
+	CustomField50    string `json:"custom_field_50" gorm:"type:text;column:custom_field_50"`
 }
 
 func (TapdBug) TableName() string {
