@@ -26,5 +26,9 @@ func All() []plugin.MigrationScript {
 	return []plugin.MigrationScript{
 		new(addInitTables),
 		new(encodeConnToken),
+		new(addTransformation),
+		new(deleteIssue),
+		new(modifyCustomFieldName),
+		new(addCustomFieldValue),
 	}
 }
