@@ -14,45 +14,25 @@
 # limitations under the License.
 
 
-from urllib.parse import urlparse, parse_qsl
-from sqlmodel import SQLModel, create_engine
+from sqlalchemy.engine import Engine
 
-from pydevlake.model import Connection, TransformationRule
+from pydevlake.model import Connection, TransformationRule, ToolScope
 
 
 class Context:
     def __init__(self,
-                 db_url: str,
-                 scope_id: str,
+                 engine: Engine,
+                 scope: ToolScope,
                  connection: Connection,
                  transformation_rule: TransformationRule = None,
                  options: dict = None):
-        self.db_url = db_url
-        self.scope_id = scope_id
+        self.engine = engine
+        self.scope = scope
         self.connection = connection
         self.transformation_rule = transformation_rule
         self.options = options or {}
         self._engine = None
 
     @property
-    def engine(self):
-        if not self._engine:
-            db_url = self.db_url
-            if not db_url:
-                raise Exception("Missing db_url setting")
-
-            # `parseTime` parameter is not understood by MySQL driver
-            # so we have to parse query args to remove it
-            connect_args = dict(parse_qsl(urlparse(self.db_url).query))
-            db_url = self.db_url.split('?')[0]
-
-            if 'parseTime' in connect_args:
-                del connect_args['parseTime']
-
-            self._engine = create_engine(db_url, connect_args=connect_args)
-            SQLModel.metadata.create_all(self._engine)
-        return self._engine
-
-    @property
-    def incremental(self):
+    def incremental(self) -> bool:
         return self.options.get('incremental') is True
