@@ -24,20 +24,23 @@ import (
 	"strings"
 	"time"
 
-	"github.com/apache/incubator-devlake/core/config"
-	"github.com/apache/incubator-devlake/core/errors"
-	"github.com/apache/incubator-devlake/impls/logruslog"
-	_ "github.com/apache/incubator-devlake/server/api/docs"
-	"github.com/apache/incubator-devlake/server/api/remote"
-	"github.com/apache/incubator-devlake/server/api/shared"
-	"github.com/apache/incubator-devlake/server/services"
-	"github.com/apache/incubator-devlake/server/services/remote/bridge"
-
 	"github.com/gin-contrib/cors"
 	"github.com/gin-gonic/gin"
-	"github.com/spf13/viper"
 	ginSwagger "github.com/swaggo/gin-swagger"
 	"github.com/swaggo/gin-swagger/swaggerFiles"
+	"github.com/swaggo/swag"
+
+	"github.com/apache/incubator-devlake/core/config"
+	"github.com/apache/incubator-devlake/core/errors"
+	"github.com/apache/incubator-devlake/core/plugin"
+	"github.com/apache/incubator-devlake/impls/logruslog"
+	_ "github.com/apache/incubator-devlake/server/api/docs"
+	"github.com/apache/incubator-devlake/server/api/login"
+	"github.com/apache/incubator-devlake/server/api/ping"
+	"github.com/apache/incubator-devlake/server/api/shared"
+	"github.com/apache/incubator-devlake/server/api/version"
+	"github.com/apache/incubator-devlake/server/services"
+	"github.com/apache/incubator-devlake/server/services/auth"
 )
 
 const DB_MIGRATION_REQUIRED = `
@@ -54,31 +57,54 @@ Alternatively, you may downgrade back to the previous DevLake version.
 // @host localhost:8080
 // @BasePath /
 func CreateApiService() {
+	// Initialize services
 	services.Init()
+	// Get configuration
 	v := config.GetConfig()
+	// Set gin mode
 	gin.SetMode(v.GetString("MODE"))
+	// Create a gin router
 	router := gin.Default()
-	remotePluginsEnabled := v.GetBool("ENABLE_REMOTE_PLUGINS")
-	if remotePluginsEnabled {
-		router.POST("/plugins/register", remote.RegisterPlugin(router, registerPluginEndpoints))
+
+	// Check if AWS Cognito is enabled
+	awsCognitoEnabled := v.GetBool("AWS_ENABLE_COGNITO")
+
+	// For both protected and unprotected routes
+	router.GET("/ping", ping.Get)
+	router.GET("/version", version.Get)
+
+	if awsCognitoEnabled {
+		// Add login endpoint
+		router.POST("/login", login.Login)
+		// Use AuthenticationMiddleware for protected routes
+		router.Use(auth.AuthenticationMiddleware)
 	}
-	// Wait for user confirmation if db migration is needed
+
+	// Endpoint to proceed database migration
 	router.GET("/proceed-db-migration", func(ctx *gin.Context) {
+		// Check if migration requires confirmation
 		if !services.MigrationRequireConfirmation() {
+			// Return success response
 			shared.ApiOutputSuccess(ctx, nil, http.StatusOK)
 			return
 		}
+		// Execute database migration
 		err := services.ExecuteMigration()
 		if err != nil {
+			// Return error response
 			shared.ApiOutputError(ctx, errors.Default.Wrap(err, "error executing migration"))
 			return
 		}
+		// Return success response
 		shared.ApiOutputSuccess(ctx, nil, http.StatusOK)
 	})
+
+	// Restrict access if database migration is required
 	router.Use(func(ctx *gin.Context) {
 		if !services.MigrationRequireConfirmation() {
 			return
 		}
+		// Return error response
 		shared.ApiOutputError(
 			ctx,
 			errors.HttpStatus(http.StatusPreconditionRequired).New(DB_MIGRATION_REQUIRED),
@@ -86,49 +112,74 @@ func CreateApiService() {
 		ctx.Abort()
 	})
 
+	// Add swagger handlers
 	router.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))
+	registerExtraOpenApiSpecs(router)
 
-	//endpoint debug log
+	// Add debug logging for endpoints
 	gin.DebugPrintRouteFunc = func(httpMethod, absolutePath, handlerName string, nuHandlers int) {
 		logruslog.Global.Printf("endpoint %v %v %v %v", httpMethod, absolutePath, handlerName, nuHandlers)
 	}
 
-	// CORS CONFIG
+	// Enable CORS
 	router.Use(cors.New(cors.Config{
-		AllowOrigins:     []string{"*"},
-		AllowMethods:     []string{"PUT", "PATCH", "POST", "GET", "OPTIONS"},
-		AllowHeaders:     []string{"Origin", "Content-Type"},
-		ExposeHeaders:    []string{"Content-Length"},
+		// Allow all origins
+		AllowOrigins: []string{"*"},
+		// Allow common methods
+		AllowMethods: []string{"PUT", "PATCH", "POST", "GET", "OPTIONS"},
+		// Allow common headers
+		AllowHeaders: []string{"Origin", "Content-Type"},
+		// Expose these headers
+		ExposeHeaders: []string{"Content-Length"},
+		// Allow credentials
 		AllowCredentials: true,
-		MaxAge:           120 * time.Hour,
+		// Cache for 2 hours
+		MaxAge: 120 * time.Hour,
 	}))
 
+	// Register API endpoints
 	RegisterRouter(router)
+	// Get port from config
 	port := v.GetString("PORT")
+	// Trim any : from the start
 	port = strings.TrimLeft(port, ":")
-	if remotePluginsEnabled {
-		go bootstrapRemotePlugins(v)
-	}
+	// Convert to int
 	portNum, err := strconv.Atoi(port)
 	if err != nil {
+		// Panic if PORT is not an int
 		panic(fmt.Errorf("PORT [%s] must be int: %s", port, err.Error()))
 	}
 
+	// Start the server
 	err = router.Run(fmt.Sprintf("0.0.0.0:%d", portNum))
 	if err != nil {
 		panic(err)
 	}
 }
 
-func bootstrapRemotePlugins(v *viper.Viper) {
-	port := v.GetString("PORT")
-	port = strings.TrimLeft(port, ":")
-	portNum, err := strconv.Atoi(port)
-	if err != nil {
-		panic(fmt.Errorf("PORT [%s] must be int: %s", port, err.Error()))
-	}
-	err = bridge.Bootstrap(v, portNum)
-	if err != nil {
-		logruslog.Global.Error(err, "")
+func registerExtraOpenApiSpecs(router *gin.Engine) {
+	for name, pluginMeta := range plugin.AllPlugins() {
+		if pluginOpenApiSpec, ok := pluginMeta.(plugin.PluginOpenApiSpec); ok {
+			spec := &swag.Spec{
+				InfoInstanceName: name,
+				SwaggerTemplate:  pluginOpenApiSpec.OpenApiSpec(),
+			}
+			swag.Register(name, spec)
+			router.GET(
+				fmt.Sprintf("/plugins/swagger/%s/*any", name),
+				ginSwagger.CustomWrapHandler(
+					&ginSwagger.Config{
+						URL:                      "doc.json",
+						DocExpansion:             "list",
+						InstanceName:             name,
+						Title:                    fmt.Sprintf("%s API", name),
+						DefaultModelsExpandDepth: 1,
+						DeepLinking:              true,
+						PersistAuthorization:     false,
+					},
+					swaggerFiles.Handler,
+				),
+			)
+		}
 	}
 }
