@@ -16,14 +16,8 @@
  *
  */
 
-import { Error } from './types';
-
 export const transformError = (error: any) => {
   switch (error?.response?.status) {
-    case 428:
-      return Error.DB_NEED_MIGRATE;
-    case 504:
-      return Error.API_OFFLINE;
     default:
       return error;
   }
