@@ -18,5 +18,4 @@
 
 export * from './update-name-dialog';
 export * from './update-policy-dialog';
-export * from './add-scope-dialog';
-export * from './update-transformation-dialog';
+export * from './connection-list';
