@@ -20,4 +20,5 @@ export * from './project';
 export * from './connection';
 export * from './blueprint';
 export * from './pipeline';
-export * from './transformation';
+export * from './offline';
+export * from './db-migrate';
