@@ -18,25 +18,46 @@
 
 import styled from 'styled-components';
 
-export const Wrapper = styled.div`
-  .block {
-    margin-bottom: 16px;
-  }
+export const Wrapper = styled.div``;
 
-  h3 {
-    margin: 0 0 8px;
-  }
+export const ConnectionColumn = styled.div`
+  display: flex;
+  align-items: center;
 
-  h4 {
-    margin: 8px 0;
+  img {
+    margin-right: 4px;
+    width: 20px;
   }
+`;
 
-  p {
-    margin: 0 0 8px;
+export const ScopeColumn = styled.ul``;
+
+export const ScopeItem = styled.li`
+  margin-bottom: 4px;
+
+  &:last-child {
+    margin-bottom: 0;
+  }
+
+  .bp4-button {
+    margin-left: 6px;
   }
+`;
+
+export const Btns = styled.div`
+  display: flex;
+  align-items: center;
+  justify-content: space-between;
+  margin-top: 36px;
+`;
+
+export const DialogTitle = styled.div`
+  display: flex;
+  align-items: center;
 
-  .bp4-button-group {
-    display: flex;
-    justify-content: flex-end;
+  img {
+    margin-right: 4px;
+    width: 24px;
+    height: 24px;
   }
 `;
