@@ -17,8 +17,10 @@
  */
 
 export * from './connection-form';
-export * from './data-scope-list';
 export * from './data-scope';
+export * from './data-scope-form';
 export * from './data-scope-miller-columns';
 export * from './data-scope-search';
 export * from './transformation';
+export * from './transformation-form';
+export * from './transformation-select';
