@@ -18,29 +18,33 @@
 
 import styled from 'styled-components';
 
-export const TransformationWrapper = styled.div`
+export const Transformation = styled.div``;
+
+export const CICD = styled.div`
   h3 {
-    margin: 0 0 8px;
+    margin-top: 16px;
 
-    .bp4-tag {
-      margin-left: 6px;
+    .switch {
+      display: inline-flex;
+      align-items: center;
+      margin-left: 16px;
+      font-size: 14px;
+      font-weight: 400;
+
+      .bp4-switch {
+        margin-bottom: 0;
+      }
     }
   }
 
-  p {
-    margin: 0 0 8px;
-  }
-
-  .bp4-form-group {
+  .text {
     display: flex;
-    align-items: center;
+    align-items: baseline;
+    margin-top: 16px;
+    padding-left: 24px;
 
-    .bp4-label {
-      flex: 0 0 150px;
-    }
-
-    .bp4-form-content {
-      flex: auto;
+    .bp4-radio {
+      margin-right: 0;
     }
   }
 `;
